==> arla_0.35.6.orig.tar.gz: arla-0.35.6/appl/bos/bos_getrestart.c <==
/*
 * Copyright (c) 1995 - 2000 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "appl_locl.h"
#include <sl.h>
#include "bos_local.h"
#include <bos.h>
#include <bos.cs.h>

RCSID("$Id: bos_getrestart.c,v 1.6 2000/10/03 00:07:07 lha Exp $");

static int
printrestart(const char *cell, const char *host,
	     int noauth, int localauth, int verbose)
{
    struct rx_connection *conn;
    struct bozo_netKTime time;
    int error;
    
    conn = arlalib_getconnbyname(cell,
				 host,
				 afsbosport,
				 BOS_SERVICE_ID,
				 arlalib_getauthflag(noauth, localauth,0,0));
    
    if (conn == NULL) {
	printf ("bos restart: failed to open connection to %s\n", host);
	return 0;
    }
    
    error = BOZO_GetRestartTime(conn, BOZO_RESTARTTIME_GENERAL, &time);
    if (error) {
	printf("bos: GetRestartTime(GENERAL) failed with: %s (%d)\n",
	       koerr_gettext(error), error);
	return 0;
    }
    printf ("Server %s restarts at %02d:%02d:%02d at day %d\n",
	    host, time.hour, time.min, time.sec, time.day);

    error = BOZO_GetRestartTime(conn, BOZO_RESTARTTIME_NEWBIN, &time);
    if (error) {
	printf("bos: GetRestartTime(NEWBIN) failed with: %s (%d)\n",
	       koerr_gettext(error), error);
	return 0;
    }
    printf ("Server %s restarts for new binaries at %02d:%02d:%02d at day %d\n",
	    host, time.hour, time.min, time.sec, time.day);
    
    arlalib_destroyconn(conn);
    return 0;
}


static int helpflag;
static const char *server;
static const char *cell;
static int noauth;
static int localauth;
static int verbose;

static struct agetargs args[] = {
    {"server",	0, aarg_string,	&server,	"server", NULL, aarg_mandatory},
    {"cell",	0, aarg_string,	&cell,		"cell",	  NULL},
    {"noauth",	0, aarg_flag,	&noauth,	"do not authenticate", NULL},
    {"local",	0, aarg_flag,	&localauth,	"localauth"},
    {"verbose",	0, aarg_flag,	&verbose,	"be verbose", NULL},
    {"help",	0, aarg_flag,	&helpflag,	NULL, NULL},
    {NULL,	0, aarg_end,	NULL,		NULL, NULL}
};

static void
usage (void)
{
    aarg_printusage (args, "bos getrestart", "", AARG_AFSSTYLE);
}

int
bos_getrestart(int argc, char **argv)
{
    int optind = 0;
    
    if (agetarg (args, argc, argv, &optind, AARG_AFSSTYLE)) {
	usage ();
	return 0;
    }
    
    if (helpflag) {
	usage ();
	return 0;
    }
    
    argc -= optind;
    argv += optind;
    
    if (server == NULL) {
	printf ("bos getrestart: missing -server\n");
	return 0;
    }
    
    if (cell == NULL)
	cell = cell_getcellbyhost (server);
    
    printrestart (cell, server, noauth, localauth, verbose);
    return 0;
}

==> arla-0.43.tar.gz: arla-0.43/appl/bos/bos_getrestart.c <==
/*
 * Copyright (c) 1995-2000, 2005 Kungliga Tekniska Hgskolan
 * (Royal Institute of Technology, Stockholm, Sweden).
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * 3. Neither the name of the Institute nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE INSTITUTE AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE INSTITUTE OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "appl_locl.h"
#include <sl.h>
#include "bos_local.h"
#include <bos.h>
#include <bos.cs.h>

RCSID("$Id: bos_getrestart.c,v 1.8 2005/03/14 21:06:06 tol Exp $");

static char *days[] = {
    "sun",
    "mon",
    "tue",
    "wed",
    "thu",
    "fri",
    "sat"
};


static void
printtime(struct bozo_netKTime *time)
{
    if (time->mask & KTIME_NEVER) {
        printf("never");
    } else if (time->mask & KTIME_NOW) {
	printf("now");
    } else {
	int ndays = sizeof(days) / sizeof(*days);
	if (time->day >= 0 && time->day < ndays) {
	    printf("at %02d:%02d:%02d at day %s",
		   time->hour, time->min, time->sec, days[time->day]);
	} else {
	    printf("unknown");
	}
    }
}

static int
printrestart(const char *cell, const char *host,
	     int noauth, int localauth, int verbose)
{
    struct rx_connection *conn;
    struct bozo_netKTime time;
    int error;
    
    conn = arlalib_getconnbyname(cell,
				 host,
				 afsbosport,
				 BOS_SERVICE_ID,
				 arlalib_getauthflag(noauth, localauth,0,0));
    
    if (conn == NULL) {
	printf ("bos restart: failed to open connection to %s\n", host);
	return 0;
    }
    
    error = BOZO_GetRestartTime(conn, BOZO_RESTARTTIME_GENERAL, &time);
    if (error) {
	printf("bos: GetRestartTime(GENERAL) failed with: %s (%d)\n",
	       koerr_gettext(error), error);
	return 0;
    }
    printf("Server %s restarts: ", host);
    printtime(&time);
    printf("\n");

    error = BOZO_GetRestartTime(conn, BOZO_RESTARTTIME_NEWBIN, &time);
    if (error) {
	printf("bos: GetRestartTime(NEWBIN) failed with: %s (%d)\n",
	       koerr_gettext(error), error);
	return 0;
    }
    printf("Server %s restarts for new binaries: ", host);
    printtime(&time);
    printf("\n");
    
    arlalib_destroyconn(conn);
    return 0;
}


static int helpflag;
static const char *server;
static const char *cell;
static int noauth;
static int localauth;
static int verbose;

static struct agetargs args[] = {
    {"server",	0, aarg_string,	&server,	"server", NULL, aarg_mandatory},
    {"cell",	0, aarg_string,	&cell,		"cell",	  NULL},
    {"noauth",	0, aarg_flag,	&noauth,	"do not authenticate", NULL},
    {"local",	0, aarg_flag,	&localauth,	"localauth"},
    {"verbose",	0, aarg_flag,	&verbose,	"be verbose", NULL},
    {"help",	0, aarg_flag,	&helpflag,	NULL, NULL},
    {NULL,	0, aarg_end,	NULL,		NULL, NULL}
};

static void
usage (void)
{
    aarg_printusage (args, "bos getrestart", "", AARG_AFSSTYLE);
}

int
bos_getrestart(int argc, char **argv)
{
    int optind = 0;
    
    if (agetarg (args, argc, argv, &optind, AARG_AFSSTYLE)) {
	usage ();
	return 0;
    }
    
    if (helpflag) {
	usage ();
	return 0;
    }
    
    argc -= optind;
    argv += optind;
    
    if (server == NULL) {
	printf ("bos getrestart: missing -server\n");
	return 0;
    }
    
    if (cell == NULL)
	cell = cell_getcellbyhost (server);
    
    printrestart (cell, server, noauth, localauth, verbose);
    return 0;
}
